PyQtGraph's Graphics Items
==========================

Since pyqtgraph relies on Qt's GraphicsView framework, most of its graphics functionality is implemented as QGraphicsItem subclasses. This has two important consequences: 1) virtually anything you want to draw can be easily accomplished using the functionality provided by Qt. 2) Many of pyqtgraph's GraphicsItem classes can be used in any normal QGraphicsScene.


Contents:

.. toctree::
    :maxdepth: 2

    plotdataitem
    plotitem
    imageitem
    graphitem
    viewbox
    linearregionitem
    infiniteline
    roi
    graphicslayout
    plotcurveitem
    scatterplotitem
    isocurveitem
    axisitem
    textitem
    errorbaritem
    arrowitem
    fillbetweenitem
    curvepoint
    curvearrow
    griditem
    scalebar
    labelitem
    vtickgroup
    legenditem
    gradienteditoritem
    histogramlutitem
    gradientlegend
    buttonitem
    graphicsobject
    graphicswidget
    graphicsitem
    uigraphicsitem
    graphicswidgetanchor

